/*####################################################################
 FILE: dht11_functions.pde - DHT11 Usage Demo.
 VERSION: 2S0A

 PURPOSE: Measure and return temperature & Humidity. Additionally provides conversions.

 LICENSE: GPL v3 (http://www.gnu.org/licenses/gpl.html)
 GET UPDATES: https://www.virtuabotix.com/

      --##--##--##--##--##--##--##--##--##--##--
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      | ##  ##  ##  ##  ##  ##  ##  ##  ##  ## |
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      | ##  ##  ##  ##  ##  ##  ##  ##  ##  ## |
      ##  ##  ##  ## DHT22 SENSOR ##  ##  ##  ##
      ##  ##  ##  ##  ##FRONT ##  ##  ##  ##  ##
      | ##  ##  ##  ##  ##  ##  ##  ##  ##  ## |
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      | ##  ##  ##  ##  ##  ##  ##  ##  ##  ## |
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      ##  ##  ##  ##  ##  ##  ##  ##  ##  ##  ##
      --##--##--##--##--##--##--##--##--##--##--
          ||       ||          || (Not    ||
          ||       ||          || Used)   ||
        VDD(5V)   Readout(I/O)          Ground

  HISTORY:
  Joseph Dattilo (Virtuabotix LLC) - Version 1S0A (14 Sep 12)
    -Converted from DHT11 2S0A library to work with the DHT22
     Portions of DHTLib used for verification, and data manipulation
     
#######################################################################*/


#include <dht22.h>

dht22 DHT220;
dht22 DHT221;

void setup()
{
  DHT220.attach(10);
  DHT221.attach(11);
  
  Serial.begin(9600);
  Serial.println("DHT22 TEST PROGRAM - two sensors ");
  Serial.print("LIBRARY VERSION: ");
  Serial.println(DHT22LIB_VERSION);
}

void loop()
{
  Serial.println("\n");

  int chk0 = DHT220.read();

  Serial.print("Read sensor 0: ");
  switch (chk0)
  {
    case 0: Serial.println("Sensor 0 OK"); break;
    case -1: Serial.println("Sensor 0 Checksum error"); break;
    case -2: Serial.println("Sensor 0 Time out error"); break;
    default: Serial.println("Sensor 0 Unknown error"); break;
  }

  Serial.print("Sensor 0 Humidity (%): ");
  Serial.println((float)DHT220.humidity, DEC);

  Serial.print("Sensor 0 Temperature (°C): ");
  Serial.println((float)DHT220.temperature, DEC);

  Serial.print("Sensor 0 Temperature (°F): ");
  Serial.println(DHT220.fahrenheit(), DEC);

  Serial.print("Sensor 0 Temperature (°K): ");
  Serial.println(DHT220.kelvin(), DEC);

  Serial.print("Sensor 0 Dew Point (°C): ");
  Serial.println(DHT220.dewPoint(), DEC);

  Serial.print("Sensor 0 Dew PointFast (°C): ");
  Serial.println(DHT220.dewPointFast(), DEC);
  Serial.print("Read sensor 0: ");
  
  int chk1 = DHT221.read();
  
  switch (chk1)
  {
    case 0: Serial.println("Sensor 1 OK"); break;
    case -1: Serial.println("Sensor 1 Checksum error"); break;
    case -2: Serial.println("Sensor 1 Time out error"); break;
    default: Serial.println("Sensor 1 Unknown error"); break;
  }

  Serial.print("Sensor 1 Humidity (%): ");
  Serial.println((float)DHT221.humidity, DEC);

  Serial.print("Sensor 1 Temperature (°C): ");
  Serial.println((float)DHT221.temperature, DEC);

  Serial.print("Sensor 1 Temperature (°F): ");
  Serial.println(DHT221.fahrenheit(), DEC);

  Serial.print("Sensor 0 Temperature (°K): ");
  Serial.println(DHT221.kelvin(), DEC);

  Serial.print("Sensor 1 Dew Point (°C): ");
  Serial.println(DHT221.dewPoint(), DEC);

  Serial.print("Sensor 1 Dew PointFast (°C): ");
  Serial.println(DHT221.dewPointFast(), DEC);

  delay(2000);
}
